@@ -4,3 +4,5 @@ from .ssm32q import AmSsm23q
 from .demo import main
 from .ks33510b import Ks33510b
 from .adam6024 import Adam6024
+from .x410 import WebRelayX410
+from .vmmd4 import VmMd40424
